@@ -1,26 +1,10 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
-                  2005 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
+    SPDX-FileCopyrightText: 2005 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "akregator_part.h"
@@ -150,13 +134,6 @@ static Part *mySelf = nullptr;
 
 Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     : KParts::Part(parent)
-    , m_standardListLoaded(false)
-    , m_shuttingDown(false)
-    , m_doCrashSave(false)
-    , m_backedUpList(false)
-    , m_mainWidget(nullptr)
-    , m_storage(nullptr)
-    , m_dialog(nullptr)
 {
     mySelf = this;
 
@@ -180,7 +157,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     QDir().mkpath(path);
     m_standardFeedList = path + QStringLiteral("/feeds.opml");
 
-    Backend::StorageFactoryDummyImpl *dummyFactory = new Backend::StorageFactoryDummyImpl();
+    auto *dummyFactory = new Backend::StorageFactoryDummyImpl();
     if (!Backend::StorageFactoryRegistry::self()->registerFactory(dummyFactory, dummyFactory->key())) {
         // There was already a dummy factory registered.
         delete dummyFactory;
@@ -292,7 +269,7 @@ void Part::slotOnShutdown()
 
 void Part::initializeTrayIcon()
 {
-    TrayIcon *trayIcon = new TrayIcon(m_mainWidget->window());
+    auto *trayIcon = new TrayIcon(m_mainWidget->window());
     TrayIcon::setInstance(trayIcon);
     m_actionManager->setTrayIcon(trayIcon);
 
@@ -432,11 +409,11 @@ bool Part::writeToTextFile(const QString &data, const QString &filename) const
     stream.setCodec("UTF-8");
     stream << data
           #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-           << endl
+        << endl
           #else
-           << Qt::endl
+        << Qt::endl
           #endif
-              ;
+    ;
     return file.commit();
 }
 
@@ -643,7 +620,6 @@ void Part::showOptions()
 #ifdef WITH_KUSERFEEDBACK
         m_dialog->addModule(QStringLiteral("akregator_config_userfeedback"));
 #endif
-
     }
 
     m_dialog->show();
