@@ -1,26 +1,10 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Teemu Rytilahti <tpr@d5k.net>
-                  2005 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2004 Teemu Rytilahti <tpr@d5k.net>
+    SPDX-FileCopyrightText: 2005 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "articleviewerwidget.h"
@@ -29,7 +13,6 @@
 #include "aboutdata.h"
 #include "actionmanager.h"
 #include "actions.h"
-#include "article.h"
 #include "articleformatter.h"
 #include "articlejobs.h"
 #include "articlematcher.h"
@@ -43,7 +26,6 @@
 
 #include <KActionCollection>
 
-#include <QUrl>
 #include <QElapsedTimer>
 
 #include <articleviewer-ng/webengine/articleviewerwebenginewidgetng.h>
@@ -61,11 +43,10 @@ using namespace Akregator::Filters;
 ArticleViewerWidget::ArticleViewerWidget(const QString &grantleeDirectory, KActionCollection *ac, QWidget *parent)
     : QWidget(parent)
     , m_node(nullptr)
-    , m_viewMode(NormalView)
     , m_articleViewerWidgetNg(new Akregator::ArticleViewerWebEngineWidgetNg(ac, this))
     , m_grantleeDirectory(grantleeDirectory)
 {
-    QGridLayout *layout = new QGridLayout(this);
+    auto *layout = new QGridLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_articleViewerWidgetNg);
     m_articleHtmlWriter = new Akregator::ArticleHtmlWebEngineWriter(m_articleViewerWidgetNg->articleViewerNg(), this);
@@ -351,7 +332,7 @@ void ArticleViewerWidget::slotArticlesListed(KJob *job)
     m_articles = m_listJob->articles();
     std::sort(m_articles.begin(), m_articles.end());
 
-    if (node && !m_articles.isEmpty()) {
+    if (!m_articles.isEmpty()) {
         m_link = m_articles.first().link();
     } else {
         m_link = QUrl();
