@@ -1,25 +1,9 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Teemu Rytilahti <tpr@d5k.net>
+    SPDX-FileCopyrightText: 2004 Teemu Rytilahti <tpr@d5k.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef AKREGATOR_ARTICLEVIEWERWIDGET_H
@@ -155,12 +139,12 @@ private:
     enum ViewMode {
         NormalView, CombinedView, SummaryView
     };
-    ViewMode m_viewMode;
+    ViewMode m_viewMode = NormalView;
     Akregator::ArticleHtmlWebEngineWriter *m_articleHtmlWriter = nullptr;
-    Akregator::ArticleViewerWebEngineWidgetNg *m_articleViewerWidgetNg = nullptr;
+    Akregator::ArticleViewerWebEngineWidgetNg *const m_articleViewerWidgetNg;
     QSharedPointer<ArticleFormatter> m_normalViewFormatter;
     QSharedPointer<ArticleFormatter> m_combinedViewFormatter;
-    QString m_grantleeDirectory;
+    const QString m_grantleeDirectory;
 };
 } // namespace Akregator
 
