@@ -1,25 +1,9 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2018 Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2018 Daniel Vrátil <dvratil@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "feedretriever.h"
@@ -47,6 +31,7 @@ void FeedRetriever::retrieveData(const QUrl &url)
 
     auto job = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
     job->addMetaData(QStringLiteral("UserAgent"), userAgent);
+    job->addMetaData(QStringLiteral("accept"), QStringLiteral("application/rss+xml;q=0.9, application/atom+xml;q=0.9, text/*;q=0.8, */*;q=0.7"));
     job->addMetaData(QStringLiteral("cache"), useCache ? QStringLiteral("refresh") : QStringLiteral("reload"));
     connect(job, &KJob::result, this, &FeedRetriever::getFinished);
     mJob = job;
