@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "grantleeviewformatter.h"
@@ -147,7 +134,7 @@ QString GrantleeViewFormatter::formatArticles(const QVector<Article> &article, A
     QList<ArticleGrantleeObject *> lstObj;
     lstObj.reserve(nbArticles);
     for (int i = 0; i < nbArticles; ++i) {
-        ArticleGrantleeObject *articleObj = new ArticleGrantleeObject(article.at(i), icon);
+        auto *articleObj = new ArticleGrantleeObject(article.at(i), icon);
         articlesList << QVariant::fromValue(static_cast<QObject *>(articleObj));
         lstObj.append(articleObj);
     }
